/*
 * muse-server
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: YoungHun Kim <yh8004.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __MUSE_SERVER_H__
#define __MUSE_SERVER_H__

#include "muse_core.h"
#include <gio/gio.h>
#include <tbm_bufmgr.h>

#ifdef __cplusplus
extern "C" {
#endif

void muse_server_set_dispatch_timeout(muse_module_h m, int api, int timeout);
int muse_server_get_dispatch_timeout(muse_module_h m, int api);

/* module */
int muse_server_module_set_value(muse_module_h m, const char *name, int value);
int muse_server_module_get_value(muse_module_h m, const char *name, int *value);
const char *muse_server_module_get_temporal_path(void);
int muse_server_module_get_msg_fd(muse_module_h m);
int muse_server_module_get_data_fd(muse_module_h m);
char *muse_server_module_get_msg(muse_module_h m);
void muse_server_set_user_data(muse_module_h m, void *data);
void *muse_server_get_user_data(muse_module_h m);
bool muse_server_module_is_valid(muse_module_h m);

/* ipc */
int muse_server_ipc_get_bufmgr(tbm_bufmgr *bufmgr);
int muse_server_ipc_get_gdbus_connection(GDBusConnection **gdbus);
char *muse_server_ipc_get_data(muse_module_h m);
void muse_server_ipc_delete_data(char *data);
bool muse_server_ipc_get_data_info(char *data, uint64_t *data_id, int *size);
intptr_t muse_server_ipc_get_handle(muse_module_h m);
int muse_server_ipc_set_handle(muse_module_h m, intptr_t handle);
int muse_server_ipc_get_fd(muse_module_h m, int *fd);
int muse_server_ipc_get_fds(muse_module_h m, int *fds, int *number);
int muse_server_ipc_set_fd(muse_module_h m, int fd);
int muse_server_ipc_get_client_pid(muse_module_h m);

/* security */
bool muse_server_security_check_cynara(int fd, const char *privilege);

/* system info */
int muse_server_get_platform_info(const char *key, bool *value);

unsigned int muse_server_get_atomic_uint(void);
int muse_server_get_module_instance_count(int idx);

bool muse_server_is_on_demand(void);

#ifdef __cplusplus
}
#endif
#endif	/*__MUSE_SERVER_H__*/
