/*
 * muse-server
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: YoungHun Kim <yh8004.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __MUSE_SERVER_CONFIG_H__
#define __MUSE_SERVER_CONFIG_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "muse_core_internal.h"
#include <iniparser.h>

#define MUSE_LOG						"muse:logfile"
#define MUSE_LOCK						"muse:lockfile"
#define MUSE_WATCHDOG_MIN_TIMEOUT				"muse:min_timeout"
#define MUSE_WATCHDOG_MAX_TIMEOUT				"muse:max_timeout"
#define MUSE_MEMORY_THRESHOLD					"muse:memory_threshold"
#define MUSE_WATCH_EXTERNAL_STORAGE				"muse:enable_watch_external_storage"
#define MUSE_ON_DEMAND_LAUNCH					"muse:on_demand"
#define MUSE_ON_DEMAND_MAX_IDLE_TIME				"muse:on_demand_max_idle_time"
#define MUSE_ON_DEMAND_MAX_IDLE_MEMORY				"muse:on_demand_max_idle_memory"
#define MUSE_GST						"muse:gstparam"
#define INI_PARSER_COLON					":"
#define PATH							"path"
#define PRELOADED						"preloaded"
#define TIMEOUT							"timeout"
#define DISABLE_WATCHDOG_API_INDEX				"disable_watchdog_api"
#define MAX_INSTANCE						"max_instance"
#define CAUTION_INSTANCE					"caution_instance"

#define DEFAULT_WATCHDOG_MIN_TIMEOUT				5
#define DEFAULT_WATCHDOG_MAX_TIMEOUT				60
#define DEFAULT_DISPATCH_WATCHDOG_TIMEOUT			10
#define DEFAULT_MEMORY_LEAK_THRESHOLD				50000 /* 50MB */
#define DEFAULT_WATCHDOG_DISABLED_API_INDEX			-1 /* Watchdog is applied to all dispatcher functions */
#define DEFAULT_MAX_INSTANCE					-1 /* Unlimited */
#define DEFAULT_CAUTION_INSTANCE				-1
#define DEFAULT_ON_DEMAND_MAX_IDLE_TIME				600 /* 10 minutes */
#define DEFAULT_ON_DEMAND_MAX_IDLE_MEMORY			30000 /* 30MB */


typedef struct host_info {
	char *path;
	char *preloaded;
	int timeout;
	int disable_watchdog_api;
	int max_instance;
	int caution_instance;
} host_info_t;

typedef struct ms_config {
	char *host[MUSE_MODULE_TYPE_MAX];
	int host_cnt;
	gboolean log_enabled;
	char *lockfile;
	int min_timeout;
	int max_timeout;
	int memory_threshold;
	gboolean is_watch_external_storage_enabled;
	char *gst_param_str[MUSE_PARAM_MAX];
	int gst_param_cnt;
	host_info_t *host_infos[MUSE_MODULE_TYPE_MAX];
	dictionary *muse_dict;
	gboolean is_on_demand;
	int max_idle_time;
	int max_idle_memory;
} ms_config_t;

void ms_config_init(ms_config_t *conf);
void ms_config_deinit(ms_config_t *conf);
char *ms_config_get_host_name(int idx);
int ms_config_get_host_cnt(void);
int ms_config_get_gst_param_cnt(void);
char *ms_config_get_gst_param_str(int idx);
char *ms_config_get_path(int idx);
char *ms_config_get_preloaded_value(int idx);
char *ms_config_get_lockfile(void);
gboolean ms_config_is_log_enabled(void);
void ms_config_remove_lockfile(void);
int ms_config_get_min_timeout(void);
int ms_config_get_max_timeout(void);
int ms_config_get_memory_threshold(void);
gboolean ms_config_is_on_demand(void);
int ms_config_get_max_idle_time(void);
int ms_config_get_timeout(int module_idx);
int ms_config_get_disable_watchdog_api(int module_idx);
int ms_config_get_max_instance(int module_idx);
int ms_config_get_caution_instance(int module_idx);
gboolean ms_config_is_external_storage_enabled(void);

#ifdef __cplusplus
}
#endif
#endif /* __MUSE_SERVER_CONFIG_H__ */
