/*
 * muse-server
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: YoungHun Kim <yh8004.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __MUSE_SERVER_CONNECTION_H__
#define __MUSE_SERVER_CONNECTION_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "muse_core_internal.h"
#include <sys/epoll.h>

#define MS_EVENT_MAX			10

typedef enum {
	MUSE_CONNECTION_STATE_INVALID,
	MUSE_CONNECTION_STATE_CONNECTED,
	MUSE_CONNECTION_STATE_DISCONNECTED,
} ms_connection_state_e;

typedef struct ms_connection {
	int epfd;
	struct epoll_event events[MS_EVENT_MAX];
	int instance_count[MUSE_MODULE_TYPE_MAX];
	GQueue *instance_queue;
	GMutex lock;
} ms_connection_t;

void ms_connection_init(ms_connection_t *connection);
void ms_connection_deinit(ms_connection_t *connection);
int ms_connection_register(muse_module_h m);
int ms_connection_unregister(muse_module_h m);
gboolean ms_connection_get_state(ms_connection_state_e *state);
void ms_connection_lock(ms_connection_t *connection);
void ms_connection_unlock(ms_connection_t *connection);

#ifdef __cplusplus
}
#endif

#endif	/*__MUSE_SERVER_CONNECTION_H__*/
