/*
 * muse-server
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: YoungHun Kim <yh8004.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __MUSE_SERVER_MODULE_H__
#define __MUSE_SERVER_MODULE_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "muse_core_internal.h"

typedef gboolean (*muse_module_dispatchfunc) (muse_module_h m);
typedef gboolean (*muse_module_cmd_dispatchfunc) (muse_module_h m);
typedef gboolean (*muse_module_callback) (GIOChannel *source, GIOCondition condition, gpointer data);

typedef struct ms_module {
	int idx;
	GMutex lock;
	gboolean loaded;
	GModule *dllsym;
	GHashTable *dllsym_table;
	int disp_timeout[API_MAX];
} ms_module_t;

void ms_module_init(ms_module_t *module);
void ms_module_deinit(ms_module_t *module);
GModule *ms_module_open(int idx);
void ms_module_dispatch_lock(muse_module_h m);
void ms_module_dispatch_unlock(muse_module_h m);
int ms_module_dispatch(muse_module_h m);
gboolean ms_module_close(muse_module_h m);
gboolean ms_module_get_loaded_dllsym(int idx);
void ms_module_set_dllsym_value(int idx, const char *name, gpointer value);
int ms_module_get_dllsym_value(int idx, const char *name, gpointer *value);
GModule *ms_module_get_dllsym(int idx);
void ms_module_set_timeout(int idx, int api, int timeout);
int ms_module_get_timeout(int idx, int api);


#ifdef __cplusplus
}
#endif

#endif	/*__MUSE_SERVER_MODULE_H__*/
