/*
 * muse-server
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: YoungHun Kim <yh8004.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __MUSE_SERVER_PRIVATE_H__
#define __MUSE_SERVER_PRIVATE_H__

#include "muse_server.h"
#include "muse_server_config.h"
#include "muse_server_connection.h"
#include "muse_server_log.h"
#include "muse_server_module.h"
#include "muse_server_signal.h"
#include "muse_server_security.h"
#include "muse_server_system.h"
#include "muse_server_watchdog.h"
#include "muse_server_tool.h"
#include <systemd/sd-daemon.h>
#include <pwd.h>
#include <grp.h>

#ifdef MUSE_TTRACE_LOG
#include <trace.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#undef LOG_TAG
#define LOG_TAG				"MUSED_SERVER"
#define MSG_KEY_PID			"pid"
#define MS_TIMEOUT_SEC			1
#define MS_TIMEOUT_MSEC			MS_TIMEOUT_SEC * 1000
#define MS_RECV_TRY_COUNT_MAX		3
#define MSG_DONE 			"DONE"

gboolean ms_ipc_create_msg_dispatch_worker(muse_module_h m);
gboolean ms_ipc_create_data_dispatch_worker(muse_module_h m);

typedef enum {
	MUSE_SERVER_STATE_IDLE,
	MUSE_SERVER_STATE_READY
} ms_state_e;

typedef struct _muse_server *muse_server_h;

typedef struct _muse_server {
	int msg_fd;
	int data_fd;
	int type;
	int stop;
	int retval;
	int pid;
	gint running;
	tbm_bufmgr bufmgr;
	GMainLoop *main_loop;
	GThread *diag_thread;
	ms_config_t *conf;
	ms_connection_t *connection;
	ms_module_t *module[MUSE_MODULE_TYPE_MAX];
	ms_log_t *log;
	ms_security_t *security;
	ms_system_t *system;
	ms_watchdog_t *watchdog;
	ms_state_e state;
	GMutex state_lock;
	struct timeval tv_s;
} muse_server_t;

typedef struct ms_cmd_dispatch_info {
	muse_module_command_e cmd;
	muse_external_storage_info_t storage;
} ms_cmd_dispatcher_info_t;

void ms_setup_syslog(void);
void ms_fork(int *notify_fd);
pid_t ms_daemonize(int *notify_fd);
void ms_daemonize_complete(int notify_fd);
void ms_gst_init(char **cmd);
int ms_pidfile_create(const char *path, pid_t pid);
void ms_init(char **argv);
muse_server_h ms_get_instance(void);
gboolean ms_check_module_idx(int idx);
ms_module_t *ms_get_module_instance(int idx);
int ms_deinit(void);
void ms_check_memory(int pid);
void ms_new(void);
int ms_open_lockfile(void);
void ms_run(void);
void ms_cmd_dispatch(muse_module_h m, muse_module_command_e cmd);
void ms_respawn(int signo);
int ms_get_pid(muse_module_h m);
void ms_log_process_info(int pid);
void ms_log_user_group_info(void);
gboolean ms_is_log_enabled(void);
int ms_kill_thread(int signo);
gboolean ms_init_bufmgr(void);
void ms_deinit_bufmgr(void);
void ms_cmd_dispatch_foreach_func(gpointer data, gpointer user_data);
void ms_set_state(ms_state_e state);
gboolean ms_is_server_ready(void);
void ms_diag_thread_create(void);
void ms_diag_thread_destroy(void);
gboolean ms_create_ready_file(void);
void ms_remove_ready_file(void);

#ifdef __cplusplus
}
#endif
#endif	/*__MUSE_SERVER_PRIVATE_H__*/
