/*
 * muse-server
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: YoungHun Kim <yh8004.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __MUSE_SERVER_SYSTEM_H__
#define __MUSE_SERVER_SYSTEM_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <glib.h>
#include <gio/gio.h>

#define MS_POWER_DBUS_MSG			"ChangeState"
#define MS_POWER_DBUS_PATH			"/Org/Tizen/System/DeviceD/PowerOff"
#define MS_POWER_DBUS_INTERFACE			"org.tizen.system.deviced.PowerOff"

#define MS_RM_DBUS_MSG				"NameOwnerChanged"
#define MS_RM_DBUS_SENDER			"org.tizen.MMResourceManager"

#define MS_DBUS_SERVICE				"org.freedesktop.DBus"
#define MS_DBUS_INTERFACE			"org.freedesktop.DBus"
#define MS_DBUS_PATH				"/org/freedesktop/DBus"

typedef struct ms_system {
	GDBusConnection *connection;
	GHashTable *platform_info_table;
	GMutex lock;
	int muse_poweroff_id;
	int muse_rm_id;
} ms_system_t;

void ms_system_init(ms_system_t *system);
void ms_system_deinit(ms_system_t *system);
gboolean ms_system_get_gdbus(GDBusConnection **connection);
void ms_system_subscribe_external_event(ms_system_t *system);
int ms_system_get_platform_info(const char *key, bool *value);
int ms_system_get_memory_usage(int pid);

#ifdef __cplusplus
}
#endif

#endif	/*__MUSE_SERVER_SYSTEM_H__*/
