/*
 * muse-server
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: YoungHun Kim <yh8004.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#include "muse_server_tool.h"
#include <fts.h>

int ms_tool_optind = 1;
int ms_tool_optopt;
char *ms_tool_optarg;

static const char *pid_file = NULL;
static const char *out_file = NULL;
static const char *err_file = NULL;
static const char *lock_file = NULL;
static bool be_verbose = FALSE;
static const char *user = NULL;
static char **muse_cmd = NULL;
static const char *cwd = "/";
static int append = 0;

static int _ms_tool_getopt(int argc, char **argv, const char *opts);

static int _ms_tool_getopt(int argc, char **argv, const char *opts)
{
	static int si = 1;
	register int ri;
	register char *cp;

	if (si == 1) {
		if (ms_tool_optind >= argc || argv[ms_tool_optind][0] != '-' || argv[ms_tool_optind][1] == '\0')
			return(EOF);
	}
	ms_tool_optopt = ri = argv[ms_tool_optind][si];
	if (ri == ':' || !(cp = strchr(opts, ri))) {
		if (argv[ms_tool_optind][++si] == '\0') {
			ms_tool_optind++;
			si = 1;
		}
		return('?');
	}
	if (*++cp == ':') {
		if (argv[ms_tool_optind][si+1] != '\0') {
			ms_tool_optarg = &argv[ms_tool_optind++][si+1];
			LOGD("%s", ms_tool_optarg);
		} else if (++ms_tool_optind >= argc) {
			LOGE(": option requires an argument - %c", ri);
			si = 1;
			return('?');
		} else {
			ms_tool_optarg = argv[ms_tool_optind++];
			LOGD("%s", ms_tool_optarg);
		}
		si = 1;
	} else {
		if (argv[ms_tool_optind][++si] == '\0') {
			si = 1;
			ms_tool_optind++;
		}
		ms_tool_optarg = NULL;
	}
	LOGD("ms_tool_optind: %d", ms_tool_optind);
	return(ri);
}

void ms_parse_params(int argc, char **argv)
{
	int opt;
	int argsLeft;

	LOGD("Enter");
	opterr = 0;

	while ((opt = _ms_tool_getopt(argc, argv, "ac:u:p:vo:e:l:")) != MUSE_ERR) {
		switch (opt) {
		case 'a':
			append = 1;
			break;
		case 'c':
			cwd = ms_tool_optarg;
			break;
		case 'p':
			pid_file = ms_tool_optarg;
			break;
		case 'v':
			be_verbose = TRUE;
			break;
		case 'u':
			user = ms_tool_optarg;
			break;
		case 'o':
			out_file = ms_tool_optarg;
			LOGD("out file: %s", out_file);
			break;
		case 'e':
			err_file = ms_tool_optarg;
			break;
		case 'l':
			lock_file = ms_tool_optarg;
			break;
		default:
			break;
		}
	}

	LOGD("ms_tool_optind: %d", ms_tool_optind);
	argsLeft = argc - ms_tool_optind;
	LOGD("argsLeft : %d", argsLeft);

	muse_cmd = &argv[ms_tool_optind];
	LOGD("cmd: %s", *muse_cmd);
	LOGD("Leave");
	return;
}

void ms_recursive_rmdir(const char *path)
{
	FTS *fts;
	FTSENT *ftsent;

	muse_return_if_fail(path);

	char *const paths[] = { (char *)path, NULL };

	fts = fts_open(paths, FTS_NOCHDIR | FTS_PHYSICAL, NULL);
	if (fts) {
		while ((ftsent = fts_read(fts))) {
			if (ftsent->fts_info == FTS_DP && ftsent->fts_level >= FTS_ROOTLEVEL)
				rmdir(ftsent->fts_accpath);
		}
		fts_close(fts);
	} else {
		LOGE("Error - null fts");
		return;
	}
}

