/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "muse_gtest_json.h"

using ::testing::InitGoogleTest;
using ::testing::Test;
using ::testing::TestCase;

class MusedTest : public ::testing::Test {
	protected:
		void SetUp() {
			std::cout << "SetUp()" << std::endl;
		}

		void TearDown() {
			std::cout << "TearDown()" << std::endl;
		}
};

TEST(MusedTest, muse_gtest_json_p)
{
	gboolean ret;
	gchar path[FILE_PATH_LEN] = {'\0', };

	snprintf(path, sizeof(path), "%s%s", (gchar *)muse_server_module_get_temporal_path(), (gchar *)SAMPLE_JSON_FILE_NAME);

	ret = muse_gtest_json(path);
	EXPECT_EQ(ret, TRUE);
}

TEST(MusedTest, muse_gtest_json_n)
{
	gboolean ret;
	gchar wrong_path[FILE_PATH_LEN] = {'\0', };

	snprintf(wrong_path, sizeof(wrong_path), "%s%s_wrong", (gchar *)muse_server_module_get_temporal_path(), (gchar *)SAMPLE_JSON_FILE_NAME);

	ret = muse_gtest_json(wrong_path);
	EXPECT_EQ(ret, FALSE);
}


TEST(MusedTest, muse_gtest_multi_threaded_json_p)
{
	gboolean ret;
	gchar path[FILE_PATH_LEN] = {'\0', };

	snprintf(path, sizeof(path), "%s%s", (gchar *)muse_server_module_get_temporal_path(), (gchar *)SAMPLE_JSON_FILE_NAME);

	ret = muse_gtest_multi_threaded_json(path);
	EXPECT_EQ(ret, TRUE);
}

TEST(MusedTest, muse_gtest_multi_threaded_json_n)
{
	gboolean ret;
	gchar wrong_path[FILE_PATH_LEN] = {'\0', };

	snprintf(wrong_path, sizeof(wrong_path), "%s%s_wrong", (gchar *)muse_server_module_get_temporal_path(), (gchar *)SAMPLE_JSON_FILE_NAME);

	ret = muse_gtest_multi_threaded_json(wrong_path);
	EXPECT_EQ(ret, FALSE);
}

TEST(MusedTest, muse_client_new_p)
{
	int client_sockfd = muse_client_new();
	ASSERT_TRUE(muse_core_fd_is_valid(client_sockfd));

	EXPECT_EQ(muse_client_close(client_sockfd), MM_ERROR_NONE);
}

TEST(MusedTest, muse_client_new_data_ch_p)
{
	int client_sockfd = muse_client_new_data_ch();
	ASSERT_TRUE(muse_core_fd_is_valid(client_sockfd));

	EXPECT_EQ(muse_client_close(client_sockfd), MM_ERROR_NONE);
}

gint main(gint argc, gchar **argv)
{
	InitGoogleTest(&argc, argv);

	return RUN_ALL_TESTS();
}
